#!/usr/bin/env python
# coding:utf-8
"""
  This file is part of SoftKnit21 framework

License
=======

 Copyright (C) <2019>  <Odile Troulet-Lamberttex@orange.fr>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or  any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.



Module purpose
==============

LC messages received from the lock controler and their payload

Implements
==========

 - B{Lock Controler Manager}

Documentation
=============

    LC messages as received by the lock controler
Usage
=====
exceptions raised only for errors from programming environement
errors which might come from transmission on serial port are not raised but logged at critical level

@author: Odile Troulet-Lambert
@copyright: Odile Troulet-Lambert
@license: AGPL
"""


import unittest
import time
from unittest.mock import patch, Mock
from LC_message_received import LCMessageReceived


def handle_error(message, LCMessage):
    """ any error found in received messages or sent messages is sent to the protocol manager
    to avoid starting the protocol manager mock this exception"""

    if isinstance(LCMessage, LCMessageReceived):
        print (f' LCMessage type : {LCMessage.mtype} , {message}')
    else:
        print(f'{message}')


class TestInitLCMessageReceived(unittest.TestCase):
    """ tests for LCMessage class constructor"""

    def setUp(self):
        # errors in LCmessages should all be trapped by tests
        # if not trapped, errors create an fsm so mock the class LCMessageError in order to see it
        patcher = patch('LC_message_received.LCMessageError', instance=True,
                        name='mockError', side_effect=handle_error)
        self.mockError = patcher.start()
        self.addCleanup(patcher.stop)

        patcher2 = patch('LC_message_abstract.LCMessageError', instance=True,
                         side_effect=handle_error)
        self.mockError2 = patcher2.start()
        self.addCleanup(patcher2.stop)

    def test_add_checksum_single_byte_message(self):
        msi = LCMessageReceived('A', None)
        msi.set_checksum(b'\x34')

        self.assertTrue(self.mockError2.call_count == 1)
        a = self.mockError2.assert_called_once()
        print ('a is None', {a is None})

    def tearDown(self):
        pass


if __name__ == '__main__':

    unittest.main()
